@@ -12,13 +12,11 @@ logger = get_task_logger(__name__)
 @task()
 def doReset():
     lemmas = loadLemmas()
-    lemma_job = group(chunks(addLemmas.si(),lemmas,10000))
+    lemma_job = group(addLemmas.si().chunks(lemmas,10000))
     wfs,spells,trans = loadWF()
-    wf_job = group(chunks(addWFS.si(),wfs,10000))
-    spell_job = group(chunks(addSpells.si(),spells,10000))
-    trans_job = group(chunks(addTrans.si(),trans,10000))
-    st = group([spell_job,
-                trans_job])
+    wf_job = group(addWFS.si().chunks(wfs,10000))
+    spell_job = group(addSpells.si().chunks(spells,10000))
+    trans_job = group(addTrans.si().chunks(trans,10000))
     res = chain(loadCats.si(), lemma_job,wf_job,spell_job,trans_job,addRelationships.si(wfs))()
     res.get()
 
