@@ -60,9 +60,7 @@ def reset(request):
         if request.method == 'POST':
             form = ResetForm(request.POST)
             if form.is_valid() and form.cleaned_data['reset']:
-                call_command('south_clear','celex', interactive=False,verbosity=0)
-                c = FreqDict.objects.create(Name='CELEX')
-                c.loadInfo()
+                doReset.delay()
                 return redirect(index)
         form = ResetForm()
         return render(request,'celex/form.html',{'form':form})
